@@ -318,7 +318,15 @@ def analyse_morphologique(img_bin, img=None):
         img (2D array):  image before binarization
         
     Returns:
-        df (dataframe): index|'x'|'long_x'| 'y'|'long_y'| 'size'|'depth'
+        df (dataframe): index|'x'|'long_x'| 'y'|'long_y'| 'size'|'depth' with :
+                - index: feature index
+                - x: gravity center x position of the feature
+                - long_x: maximum feature width
+                - y: gravity center y position of the feature
+                - long_y: maximum feature height
+                - size: pixels number of the feature 
+                - depth : feature depth
+        
     '''
     
     # 3rd party import
@@ -384,16 +392,17 @@ def Otsu_tresholding(im,Ostu_corr=1):
     im_bin = np.where((convert(im) < thresh_otsu/Ostu_corr), 1, 0)
     return im_bin
 
-def top_hat_flattening(im,struct_elmt_size):
+def top_hat_flattening(im, struct_elmt_size, top_hat_sens=1):
 
     ''' 
-    mise à plat de l image en appliquant une transformation top hat à chacune
-    des lignes de l image im
+    Image flattening using a 1 D morphological top hat filter to each row of the image 
     
     Arguments:
         im (2D array): image to process
         struct_elmt_size (int): length of the structure element (must be larger then
-            the larger length of the feature of interest)
+            the larger length of the feature of interest)int)
+        top_hat_sens (int): +1 for bumpy features
+                            -1 for hollow featues
     Returns:
         Ip (2D array) : processed image
     '''
@@ -402,11 +411,15 @@ def top_hat_flattening(im,struct_elmt_size):
     from scipy.ndimage import white_tophat
     import numpy as np 
     
+    if top_hat_sens == -1 : im = -im
+    
     (mx,my)=np.shape(im)
     Ip=[]
     for ii in range(mx):
         Ip.append(white_tophat(im[ii,:], None, np.repeat([1], struct_elmt_size)))
     Ip=np.array(Ip).reshape((mx,my))
+    
+    if top_hat_sens == -1 : Ip = -Ip
 
     return Ip
 
